.. Brome documentation master file, created by
   sphinx-quickstart on Thu Sep 17 08:22:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Brome's documentation!
=================================

.. image:: https://img.shields.io/travis/brome-hq/brome.svg
        :target: https://travis-ci.org/brome-hq/brome

.. image:: https://img.shields.io/pypi/v/brome.svg
        :target: https://pypi.python.org/pypi/brome

.. image:: https://readthedocs.org/projects/brome/badge/?version=latest
    :target: http://brome.readthedocs.org/en/release
    :alt: Documentation Status

Brome is a Framework for Selenium

Documentation
-------------

.. toctree::
   :maxdepth: 1

   installation
   configuration
   brome
   location
   waiting
   interaction
   assertion
   browsers
   state
   network
   session_recording
   resources

Features
--------

* Simple API
* Focused on test stability and uniformity
* Highly configurable
* Runner for Amazon EC2, Saucelabs, Browserstack, Virtualbox and Appium
* Javascript implementation of select, drag and drop, scroll into view
* IPython embed on assertion for debugging
* Session Video recording
* Network capture with mitmproxy (firefox & chrome)
* Persistent test report
* Webserver
* Test state persistence system
* Support mobile easier (e.g.: click use Touch)
